#undef QT_NO_STL
#undef QT_NO_STL_WCHAR

#ifndef NULL
#define NULL    0
#endif

#include "pyside_global.h"

#include <authservice.h>
#include <authsession.h>
#include <indentity.h>
#include <sessiondata.h>
#include <signon.h>
#include <identityinfo.h>
#include <error.h>
