#undef QT_NO_STL
#undef QT_NO_STL_WCHAR

#ifndef NULL
#define NULL    0
#endif

#include "pyside_global.h"

#include <AccountSetup/provider-plugin-proxy.h>
#include <AccountSetup/provider-plugin-process.h>
